/**************************************************************************/
/*  Klavaro - a flexible touch typing tutor                               */
/*  Copyright (C) 2005 - 2008  Felipe Castro                              */
/*                                                                        */
/*  This program is free software, licensed under the terms of the GNU    */
/*  General Public License as published by the Free Software Foundation,  */
/*  which is also included in this package, in a file named "COPYING".    */
/**************************************************************************/

#define MAX_WORDS 3000

/*
 * Interface functions
 */
gchar *velo_get_dict_name (void);

void velo_reset_dict (void);

/*
 * Auxiliar functions
 */
void velo_init (void);

void velo_init_dict (gchar *);

void velo_draw_random_words (void);

void velo_get_random_word (gchar *);

gchar *velo_filter_utf8 (gchar * text);

void velo_text_write_to_file (gchar * text_raw, gboolean overwrite);

void velo_create_dict (gchar * file_name, gboolean overwrite);

void velo_comment (gdouble accuracy, gdouble velocity);
